@@ -4,8 +4,8 @@ odfWeaveControl <- function(
    verbose = TRUE,
    plotType = "png",
    plotDevice = ifelse(.Platform$OS.type == "windows", "png", "bitmap"),
-   plotHeight = ifelse(plotType %in% c("jpg", "png", "gif", "bmp"), 480, 6),
-   plotWidth = ifelse(plotType %in% c("jpg", "png", "gif", "bmp"), 480, 6),
+   plotHeight = ifelse(plotDevice %in% c("jpeg", "png", "bmp"), 480, 6),
+   plotWidth = ifelse(plotDevice %in% c("jpeg", "png", "bmp"), 480, 6),
    dispHeight = 4.5,
    dispWidth = 4.5)
 {
